@@ -614,7 +614,7 @@ void latentgev(int *n, double *data, int *nSite, int *nObs, int *covmod,
   }
   GetRNGstate();
   
-  for (int i=10;i--;){
+  for (int i=0;i<9;i++){
     accRates[i] /= (double) iter;
     extRates[i] /= (double) iter;
   }
